@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -21,22 +21,32 @@
 # @param soloc the build directory
 # @param code model code
 # @param udll logical; if FALSE, a random dll name is generated
-new_build <- function(file, model, project, soloc, code=NULL, 
+new_build <- function(file, model, project, soloc, code = NULL, 
                       preclean = FALSE, udll = FALSE) {
   
-  if(is.null(model)) model <- tools::file_path_sans_ext(file)
-  
-  if(file == ".cpp") stop("invalid file and/or model argument", call. = FALSE)
+  if(length(model) == 0) {
+    stop("invalid model name", call. = FALSE)
+  }
   
   if(charthere(model," ")) {
     stop("model name cannot contain spaces.", call. = FALSE)
   }
   
-  if(any(charthere(project,"\n"))) {
-    stop("project argument contains newline(s); did you mean to call mcode?",call.=FALSE) 
+  if(is.null(file)) {
+    file <- paste0(model,".cpp")
   }
-
+  
+  new_model <- gsub(".", "_", model, fixed = TRUE)
+  
+  if(any(charthere(project,"\n"))) {
+    stop(
+      "project argument contains newline(s); did you mean to call mcode?",
+      call.=FALSE
+    ) 
+  }
+  
   env <- new.env()
+  
   env$win <- .Platform$OS.type=="windows"
   
   ## Both project and soloc get normalized
@@ -46,16 +56,15 @@ new_build <- function(file, model, project, soloc, code=NULL,
   
   soloc <-   normalizePath(soloc, mustWork=TRUE, winslash="/")
   
-  env$soloc <-   as.character(create_soloc(soloc,model,preclean))
+  env$soloc <- as.character(create_soloc(soloc,new_model,preclean))
   
-  if(!file_readable(project)) {
+  env$project <- normalizePath(project, mustWork=TRUE, winslash="/")  
+  
+  if(!file_readable(env$project)) {
     stop("project directory must exist and be readable.",call.=FALSE) 
   }
   
-  env$project <- normalizePath(project, mustWork=TRUE, winslash="/")
-  
-  ## The model file is <stem>.cpp in the <project> directory if a
-  env$modfile <- file.path(project,file)
+  env$modfile <- file.path(env$project,file)
   
   ## If code is passed in as character:
   if(is.character(code)) {
@@ -65,22 +74,29 @@ new_build <- function(file, model, project, soloc, code=NULL,
   }
   
   if(!file_exists(env$modfile)) {
-    stop("The model file ", basename(env$modfile), " does not exist.",call.=FALSE) 
+    new_modfile <- file.path(env$project,model)
+    if(!file_exists(new_modfile)) {
+      stop("the model file ", 
+           basename(env$modfile), 
+           " does not exist.",call.=FALSE) 
+    } else {
+      env$modfile <- new_modfile  
+    }
   }
   
   env$md5 <- tools::md5sum(env$modfile)
   
-  env$package <- ifelse(udll,rfile(model), model)
+  env$package <- ifelse(udll, rfile(model), new_model)
   
-  env$compfile <- compfile(model)
-  env$compbase <- compbase(model)
-  env$compout <- compout(model)
+  env$compfile <- compfile(new_model)
+  env$compbase <- compbase(new_model)
+  env$compout <- compout(new_model)
   env$compdir <- compdir()
   env$cachfile <- cachefile()
-  env$model <- model
+  env$model <- new_model
   
   return(env)
-
+  
 }
 
 rfile <- function(pattern="",tmpdir=normalizePath(getwd(),winslash="/")){
