@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -17,13 +17,17 @@
 
 
 
-##' Select and modify a idata set for simulation.
+##' Select and modify a idata set for simulation
 ##'
 ##' @param x model object
 ##' @param data a data set coercable to data.frame
-##' @param object character name of an object existing in \code{$ENV} to use for the data set
-##' @param subset passed to \code{dplyr::filter_}
-##' @param select passed to \code{dplyr::select_}
+##' @param object character name of an object existing in \code{$ENV} 
+##' to use for the data set
+##' @param .subset an unquoted expression passed to 
+##' \code{dplyr::filter}; retain only certain rows in the data set
+##' @param .select passed to \code{dplyr::select}; retain only certain 
+##' columns in the data set; this should be the result of a call to 
+##' \code{dplyr::vars()}
 ##' @param need passed to \code{\link{inventory}}
 ##' @param ... passed along
 ##' 
@@ -70,23 +74,29 @@
 ##' @seealso \code{\link{data_set}}, \code{\link{ev}}
 ##' 
 ##' @export
-setGeneric("idata_set", function(x,data,...) standardGeneric("idata_set"))
+setGeneric("idata_set", function(x,data,...) {
+  standardGeneric("idata_set")
+})
 
 ##' @rdname idata_set
 ##' @export
-setMethod("idata_set", c("mrgmod", "data.frame"), function(x,data,subset=TRUE,select=TRUE,object=NULL,need=NULL,...) {
-            
+setMethod("idata_set", c("mrgmod", "data.frame"), function(x,data,.subset=TRUE,.select=TRUE,object=NULL,need=NULL,...) {
+  
   if(is.character(need)) suppressMessages(inventory(x,data,need))
-  if(exists("idata", x@args)) stop("idata has already been set.")
-  if(!missing(subset)) data <- filter_(data,.dots=lazy(subset))
-  if(!missing(select)) data <- select_(data,.dots=lazy(select))
+  
+  if(!missing(.subset)) {
+    data <- filter(data,`!!!`(enquo(.subset)))
+  }
+  if(!missing(.select)) {
+    data <- select(data,`!!!`(.select))
+  }
   if(nrow(data)==0) {
-    stop("Zero rows in idata after filtering.", call.=FALSE)
+    stop("zero rows in idata after filtering.", call.=FALSE)
   }
   if(is.character(object)) {
     data <- data_hooks(data,object,x@envir,param(x),...) 
   }
-  x@args <- merge(x@args,list(idata=as.data.frame(data)), open=TRUE)
+  x@args[["idata"]] <- as.data.frame(data)
   return(x)
   
 })
