@@ -29,8 +29,6 @@ class datarecord;
 typedef boost::shared_ptr<datarecord> rec_ptr;
 typedef std::vector<rec_ptr> reclist;
 
-void add_mtime(reclist& thisi, dvec& b, dvec& c, bool debug);
-
 #define NEWREC boost::make_shared<datarecord>
 
 class datarecord {
@@ -94,11 +92,11 @@ public:
   void steady_bolus(odeproblem* prob);
   void steady(odeproblem* prob, double Fn);
   
-  bool infusion(){return (Evid==1) && (Rate > 0);}
-  bool int_infusion(){return (Evid==1) && (Rate > 0) && (Amt > 0);}
-  bool ss_int_infusion(){return (Evid==1) && (Rate > 0) && (Amt > 0) && (Ss > 0);}
+  bool infusion(){return (Evid==1 || Evid==4 || Evid==5) && (Rate > 0);}
+  bool int_infusion(){return (Evid==1 || Evid==4 || Evid==5) && (Rate > 0) && (Amt > 0);}
+  bool ss_int_infusion(){return (Evid==1 || Evid ==4 || Evid==5) && (Rate > 0) && (Amt > 0) && (Ss > 0);}
   bool const_infusion(){return (Evid==1) && (Rate > 0) && (Amt == 0);}
-  bool is_event() {return (Evid != 0) && (Evid != 2) ;}
+  bool is_event() {return (Evid > 0);}
   bool is_dose(){return Evid==1;}
   bool is_event_data() {return (Evid != 0) && (Evid != 2) && Fromdata;}
   bool needs_sorting(){return ((Addl > 0) || (Ss == 1));}
@@ -124,7 +122,6 @@ protected:
   double Amt; ///< record dosing amount value
   double Rate; ///< record infusion rate value
   double Ii; ///< record inter-dose interval value
-  double Fn; ///< record bioavailability value
   bool Armed; ///< only armed records are actually executed
   
 };
