@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -34,8 +34,6 @@ test_that("event requirements and defaults", {
   expect_equal(df$cmt,1)
 })
 
-
-
 test_that("collection of events", {
   e1 <- ev(amt=200)
   e2 <- ev(amt=100,time=1)
@@ -46,7 +44,6 @@ test_that("collection of events", {
   expect_equal(e$amt, c(200,100))
 })
 
-
 test_that("realized events", {
   e <- as.data.frame(ev(amt=100, ii=24, addl=4))
   expect_equal(nrow(e),1)
@@ -63,8 +60,6 @@ test_that("realized events", {
 })
 
 test_that("realized event error", {
-  expect_error(ev(amt=100, realize_addl=TRUE))
-  expect_error(ev(amt=100, ii=24, realize_addl=TRUE))
   expect_error(ev(amt=100, addl=24, realize_addl=TRUE))
 })
 
@@ -80,26 +75,18 @@ test_that("sequence of event objects", {
   expect_equal(e$time, c(0,96, 144))
   
   e <- seq(e1, wait = 20, e2, wait= -10, e3)
-  
   e <- as.data.frame(e)
-  
   expect_equal(nrow(e), 3)
   expect_equal(e$time, c(0,116,154))
-  
   expect_is(seq(e2, e1, wait=2, e1),"ev")
-
+  
 })
 
 test_that("replicate an event object", {
-  
   e1 <- ev(amt=1, ii=24, addl=3)
- 
   df <- ev_rep(e1, 11:14)
-  
   expect_is(df, "data.frame")
-  
   expect_equal(df$ID, 11:14)
-  
 })
 
 test_that("events with without rate" , {
@@ -111,3 +98,67 @@ test_that("events with without rate" , {
   expect_equal(e$rate,c(0,1))
 })
 
+test_that("coerce to data frame", {
+  e <- ev(amt = 100)
+  
+  ans <- as.data.frame(e)
+  expect_is(ans, "data.frame")
+  expect_false(mrgsolve:::has_ID(ans))
+  
+  ans <- as.data.frame(e, add_ID = 2)
+  expect_is(ans, "data.frame")
+  expect_true(mrgsolve:::has_ID(ans))
+  expect_equal(ans$ID, 2)
+  
+  e <- ev(amt = 100, ID = 4)
+  ans <- as.data.frame(e, add_ID = 2)
+  expect_equal(ans$ID, 4)
+})
+
+
+test_that("get names", {
+  e <- ev(amt = 100, time = 0, evid = 1, ii = 12, addl = 24)
+  expect_equal(names(e), c("time", "cmt", "amt", "ii", "addl", "evid"))
+})
+
+test_that("mutate an ev object", {
+    e <- ev(amt = 100, cmt = 1)
+    e2 <- mutate(e, cmt = 2)
+    expect_is(e2, "ev")
+    df <- as.data.frame(e2)
+    expect_equal(df$cmt, 2)
+})
+
+test_that("filter an ev object", {
+  e <- ev(amt = 100, cmt = 1, ii = 24, addl = 13)
+  e <- realize_addl(e)
+  e2 <- filter(e, time > 100) %>% as.data.frame()
+  expect_true(all(e2[["time"]] > 100))
+})
+
+test_that("misc methods", {
+    e <- ev(amt = 100)
+    expect_true(mrgsolve:::is.ev(e))
+    expect_false(mrgsolve:::is.ev(as.data.frame(e)))
+})
+
+test_that("as.ev", {
+  df <- data_frame(amt = 100, foo = 5)
+  d <- as.data.frame(as.ev(df))
+  expect_equal(d$cmt,1)
+  expect_equal(d$amt,100)
+  expect_equal(d$evid,1)
+  expect_equal(d$time,0)
+  expect_equal(d$foo,5)
+  
+  df <- data_frame(amt = 200, evid = 1)
+  obs <- mutate(df, evid = 0)
+  df <- bind_rows(df,obs)
+  d <- as.data.frame(as.ev(df))
+  
+  expect_equal(d$evid,1)
+  
+})
+
+
+
