@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -30,7 +30,6 @@ $OMEGA 0 0 0
 $SIGMA 0 0 0
 '
 
-
 mod <- mcode("test4",code,compile=FALSE)
 
 
@@ -38,7 +37,6 @@ mod <- mod %>%
   omat(diag(c(1.2, 2.3,3.4))) %>% 
   smat(diag(c(0.1, 0.2, 0.3)))
 
-
 test_that("Indexing OMEGA matrix elements", {
   expect_equivalent(as.matrix(omat(mod))[2,2],2.3)
   expect_equivalent(as.matrix(omat(mod))[2,1],0)
@@ -65,8 +63,17 @@ test_that("Indexing OMEGA matrix elements with multiple matrices", {
     expect_equivalent(mat[9,8],98)
 })
 
+test_that("Update a model with no matrix", {
+  mod@omega <- omat()
+  expect_is(omat(mod, list()), "mrgmod")
+  expect_is(omat(mod, matrix(0,0,0)), "mrgmod")  
+  expect_error(omat(mod, dmat(1,2,3)), "improper signature")
+})
 
-
+test_that("Update a model matrix", {
+  expect_is(omat(mod, dmat(55,66,77)), "mrgmod")  
+  expect_error(omat(mod, dmat(1)))  
+})
 
 
 
