@@ -1,4 +1,4 @@
-# Copyright (C) 2013 - 2017  Metrum Research Group, LLC
+# Copyright (C) 2013 - 2018  Metrum Research Group, LLC
 #
 # This file is part of mrgsolve.
 #
@@ -45,21 +45,19 @@ test_that("Parse matrix", {
 
 test_that("Parse capture", {
   
-  code <- "$CAPTURE\n yes=TRUE \n z a"
+  code <- "$CAPTURE\n  \n banana = b z apple = a"
   mod <- mtemp(code)
-  expect_equal(mod@capture, c("z", "a"))
+  expect_equal(mod@capture, c(b = "banana", z = "z", a = "apple"))
   
-  code <- "$CAPTURE\n yes=TRUE \n z a \n\n\n d\n e, f"
+  code <- "$CAPTURE\n  z a \n\n\n d\n e, f"
   mod <- mtemp(code)
-  expect_equal(mod@capture, c("z", "a", "d", "e", "f"))
+  expect_equal(mod@capture, c(z = "z", a = "a", d = "d", e = "e", f = "f"))
+  
   
-  code <- "$CAPTURE >> yes=TRUE \n z a \n\n\n d\n e, f"
-  mod <- mtemp(code)
-  expect_equal(mod@capture, c("z", "a", "d", "e", "f"))
   
   code <- "$CAPTURE \n"
   expect_warning(mod <- mtemp(code))
-  expect_equal(mod@capture, character(0))
+  expect_equivalent(mod@capture, character(0))
   
 })
 
@@ -121,13 +119,13 @@ test_that("Commented model", {
   double b = 3;
   ## 234234
   $CAPTURE 
-    KA // Capturing KA
+    kaya = KA // Capturing KA
   ' 
   
   expect_is(mod <- mcode("commented", code,compile=FALSE),"mrgmod")
   expect_identical(param(mod),param(CL=2,VC=10,KA=3))
   expect_identical(init(mod),init(x=0,y=3,h=3))
-  expect_identical(mod@capture, c("KA","a"))
+  expect_identical(mod@capture, c(KA = "kaya",a = "a"))
   
 })
 
